@@ -5,8 +5,8 @@ import shutil
 import socket
 import datetime
 import subprocess
-import numpy as np
 
+import numpy as np
 import ase.io
 import ase.build
 
@@ -14,7 +14,7 @@ from ase.calculators.calculator import (CalculationFailed, Calculator,
                                         CalculatorSetupError, Parameters,
                                         all_changes, register_calculator_class)
 
-__version__ = "0.2.6"
+__version__ = "0.2.7"
 __license__ = "MIT"
 __author__ = "Michael F. Herbst"
 __all__ = ["DFTK", "update", "build_sysimage", "remove_sysimage"]
@@ -224,6 +224,10 @@ class DFTK(Calculator):
             raise CalculatorSetupError("An Atoms object must be present "
                                        "in the calculator to use write")
 
+        # Normalise a few parameters, otherwise json serialisation has trouble
+        if isinstance(self.parameters["kpts"], np.ndarray):
+            self.parameters["kpts"] = self.parameters["kpts"].tolist()
+
         with io.StringIO() as fp:
             ase.io.write(fp, self.atoms.copy(), format="json")
             atoms_json = fp.getvalue()
